@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-__version__ = "1.16.0"
+__version__ = "1.17.1"
 
 
 import asyncio
@@ -57,9 +57,17 @@ __all__ = [
     "BleakAbortedError",
     "BleakNotFoundError",
     "BleakDisconnectedError",
+    "BLEAK_RETRY_EXCEPTIONS",
 ]
 
+
 BLEAK_EXCEPTIONS = (AttributeError, BleakError)
+BLEAK_RETRY_EXCEPTIONS = (
+    *BLEAK_EXCEPTIONS,
+    EOFError,
+    BrokenPipeError,
+    asyncio.TimeoutError,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -77,7 +85,7 @@ BLEAK_TIMEOUT = 14.25
 # since the dbus connection can stall
 # so we have an additional timeout to
 # be sure we do not block forever
-BLEAK_SAFETY_TIMEOUT = 15.75
+BLEAK_SAFETY_TIMEOUT = 20
 
 # These errors are transient with dbus, and we should retry
 TRANSIENT_ERRORS = {"le-connection-abort-by-local", "br-connection-canceled"}
@@ -535,7 +543,7 @@ async def establish_connection(
                 attempt,
                 device.rssi,
             )
-            await wait_for_disconnect(device, 0)
+            await wait_for_disconnect(device, BLEAK_DBUS_BACKOFF_TIME)
             _raise_if_needed(name, description, exc)
         except BrokenPipeError as exc:
             # BrokenPipeError is raised by dbus-next when the device disconnects
